@@ -25,7 +25,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *	$Id: syscall.h,v 1.55 2007/08/02 01:37:55 roland Exp $
+ *	$Id: syscall.h,v 1.57 2008/05/20 04:56:22 roland Exp $
  */
 
 #include "dummy.h"
@@ -104,6 +104,7 @@ int sys_arch_prctl();
 int sys_io_setup(), sys_io_submit(), sys_io_cancel(), sys_io_getevents(), sys_io_destroy();
 int sys_utimensat(), sys_epoll_pwait(), sys_signalfd(), sys_timerfd(), sys_eventfd();
 int sys_getcpu();
+int sys_fallocate(), sys_timerfd_create(), sys_timerfd_settime(), sys_timerfd_gettime();
 
 /* sys_socketcall subcalls */
 
@@ -317,3 +318,5 @@ int sys_capget(), sys_capset();
 #ifdef M68K
 int sys_cacheflush();
 #endif
+
+int sys_pread64(), sys_pwrite64();
